@@ -74,10 +74,10 @@ QString RubyClassifierCodeDocument::getPath()
     path = path.simplified();
 
     // Replace all blanks with underscore
-    path.replace(QRegExp(" "), "_");
+    path.replace(QRegExp(QLatin1String(" ")), QLatin1String("_"));
 
-    path.replace(QRegExp("\\."),"/");
-    path.replace(QRegExp("::"), "/");
+    path.replace(QRegExp(QLatin1String("\\.")),QLatin1String("/"));
+    path.replace(QRegExp(QLatin1String("::")), QLatin1String("/"));
 
     path = path.toLower();
 
@@ -93,7 +93,7 @@ QString RubyClassifierCodeDocument::getRubyClassName(const QString &name)
 // Initialize this ruby classifier code document
 void RubyClassifierCodeDocument::init()
 {
-    setFileExtension(".rb");
+    setFileExtension(QLatin1String(".rb"));
 
     //initCodeClassFields(); // this is dubious because it calls down to
                              // CodeGenFactory::newCodeClassField(this)
@@ -124,7 +124,7 @@ void RubyClassifierCodeDocument::init()
 bool RubyClassifierCodeDocument::addCodeOperation(CodeOperation * op)
 {
     Uml::Visibility::Enum scope = op->getParentOperation()->visibility();
-    if(!op->getParentOperation()->isConstructorOperation())
+    if (!op->getParentOperation()->isConstructorOperation())
     {
         switch (scope) {
         default:
@@ -168,10 +168,10 @@ void RubyClassifierCodeDocument::loadChildTextBlocksFromNode(QDomElement & root)
     QDomNode tnode = root.firstChild();
     QDomElement telement = tnode.toElement();
     bool loadCheckForChildrenOK = false;
-    while(!telement.isNull()) {
+    while (!telement.isNull()) {
         QString nodeName = telement.tagName();
 
-        if(nodeName == "textblocks") {
+        if (nodeName == QLatin1String("textblocks")) {
 
             QDomNode node = telement.firstChild();
             QDomElement element = node.toElement();
@@ -179,100 +179,88 @@ void RubyClassifierCodeDocument::loadChildTextBlocksFromNode(QDomElement & root)
             // if there is nothing to begin with, then we don't worry about it
             loadCheckForChildrenOK = element.isNull() ? true : false;
 
-            while(!element.isNull()) {
+            while (!element.isNull()) {
                 QString name = element.tagName();
 
-                if(name == "codecomment") {
+                if (name == QLatin1String("codecomment")) {
                     CodeComment * block = new RubyCodeComment(this);
                     block->loadFromXMI(element);
-                    if(!addTextBlock(block))
-                    {
+                    if (!addTextBlock(block)) {
                         uError()<<"loadFromXMI : unable to add codeComment to :"<<this;
                         delete block;
-                    } else
+                    } else {
                         loadCheckForChildrenOK= true;
-                } else
-                    if(name == "codeaccessormethod" ||
-                            name == "ccfdeclarationcodeblock"
-                     ) {
-                        QString acctag = element.attribute("tag","");
-                        // search for our method in the
-                        TextBlock * tb = findCodeClassFieldTextBlockByTag(acctag);
-                        if(!tb || !addTextBlock(tb))
-                        {
-                            uError()<<"loadFromXMI : unable to add codeclassfield child method to:"<<this;
-                            // DON'T delete
-                        } else
+                    }
+                } else if (name == QLatin1String("codeaccessormethod") ||
+                           name == QLatin1String("ccfdeclarationcodeblock")) {
+                    QString acctag = element.attribute(QLatin1String("tag"));
+                    // search for our method in the
+                    TextBlock * tb = findCodeClassFieldTextBlockByTag(acctag);
+                    if (!tb || !addTextBlock(tb)) {
+                        uError()<<"loadFromXMI : unable to add codeclassfield child method to:"<<this;
+                        // DON'T delete
+                    } else {
+                        loadCheckForChildrenOK= true;
+                    }
+                } else if (name == QLatin1String("codeblock")) {
+                    CodeBlock * block = newCodeBlock();
+                    block->loadFromXMI(element);
+                    if (!addTextBlock(block)) {
+                        uError()<<"loadFromXMI : unable to add codeBlock to :"<<this;
+                        delete block;
+                    } else {
+                        loadCheckForChildrenOK= true;
+                    }
+                } else if (name == QLatin1String("codeblockwithcomments")) {
+                    CodeBlockWithComments * block = newCodeBlockWithComments();
+                    block->loadFromXMI(element);
+                    if (!addTextBlock(block)) {
+                        uError()<<"loadFromXMI : unable to add codeBlockwithcomments to:"<<this;
+                        delete block;
+                    } else {
+                        loadCheckForChildrenOK= true;
+                    }
+                } else if (name == QLatin1String("header")) {
+                    // do nothing.. this is treated elsewhere
+                } else if (name == QLatin1String("hierarchicalcodeblock")) {
+                    HierarchicalCodeBlock * block = newHierarchicalCodeBlock();
+                    block->loadFromXMI(element);
+                    if (!addTextBlock(block)) {
+                        uError()<<"Unable to add hierarchicalcodeBlock to:"<<this;
+                        delete block;
+                    } else {
+                        loadCheckForChildrenOK= true;
+                    }
+                } else if (name == QLatin1String("codeoperation")) {
+                    // find the code operation by id
+                    QString id = element.attribute(QLatin1String("parent_id"), QLatin1String("-1"));
+                    UMLObject * obj = UMLApp::app()->document()->findObjectById(Uml::ID::fromString(id));
+                    UMLOperation * op = dynamic_cast<UMLOperation*>(obj);
+                    if (op) {
+                        CodeOperation * block = new RubyCodeOperation(this, op);
+                        block->loadFromXMI(element);
+                        if (addTextBlock(block)) {
                             loadCheckForChildrenOK= true;
-
-                    } else
-                        if(name == "codeblock") {
-                            CodeBlock * block = newCodeBlock();
-                            block->loadFromXMI(element);
-                            if(!addTextBlock(block))
-                            {
-                                uError()<<"loadFromXMI : unable to add codeBlock to :"<<this;
-                                delete block;
-                            } else
-                                loadCheckForChildrenOK= true;
-                        } else
-                            if(name == "codeblockwithcomments") {
-                                CodeBlockWithComments * block = newCodeBlockWithComments();
-                                block->loadFromXMI(element);
-                                if(!addTextBlock(block))
-                                {
-                                    uError()<<"loadFromXMI : unable to add codeBlockwithcomments to:"<<this;
-                                    delete block;
-                                } else
-                                    loadCheckForChildrenOK= true;
-                            } else
-                                if(name == "header") {
-                                    // do nothing.. this is treated elsewhere
-                                } else
-                                    if(name == "hierarchicalcodeblock") {
-                                        HierarchicalCodeBlock * block = newHierarchicalCodeBlock();
-                                        block->loadFromXMI(element);
-                                        if(!addTextBlock(block))
-                                        {
-                                            uError()<<"Unable to add hierarchicalcodeBlock to:"<<this;
-                                            delete block;
-                                        } else
-                                            loadCheckForChildrenOK= true;
-                                    } else
-                                        if(name == "codeoperation") {
-                                            // find the code operation by id
-                                            QString id = element.attribute("parent_id","-1");
-                                            UMLObject * obj = UMLApp::app()->document()->findObjectById(Uml::ID::fromString(id));
-                                            UMLOperation * op = dynamic_cast<UMLOperation*>(obj);
-                                            if(op) {
-                                                CodeOperation * block = new RubyCodeOperation(this, op);
-                                                block->loadFromXMI(element);
-                                                if(addTextBlock(block))
-                                                    loadCheckForChildrenOK= true;
-                                                else
-                                                {
-                                                    uError()<<"Unable to add codeoperation to:"<<this;
-                                                    block->deleteLater();
-                                                }
-                                            } else
-                                                uError()<<"Unable to find operation create codeoperation for:"<<this;
-                                        } else
-                                            if(name == "rubyclassdeclarationblock")
-                                            {
-                                                RubyClassDeclarationBlock * block = getClassDecl();
-                                                block->loadFromXMI(element);
-                                                if(!addTextBlock(block))
-                                                {
-                                                    uError()<<"Unable to add ruby code declaration block to:"<<this;
-                                                    // DON'T delete.
-                                                    // block->deleteLater();
-                                                } else
-                                                    loadCheckForChildrenOK= true;
-                                            }
-                // This last item is only needed for extreme debugging conditions
-                // (E.g. making new codeclassdocument loader)
-                // else
-                //        uDebug()<<" LoadFromXMI: Got strange tag in text block stack:"<<name<<", ignorning";
+                        } else {
+                            uError()<<"Unable to add codeoperation to:"<<this;
+                            block->deleteLater();
+                        }
+                    } else {
+                        uError()<<"Unable to find operation create codeoperation for:"<<this;
+                    }
+                } else if (name == QLatin1String("rubyclassdeclarationblock")) {
+                    RubyClassDeclarationBlock * block = getClassDecl();
+                    block->loadFromXMI(element);
+                    if (!addTextBlock(block)) {
+                        uError()<<"Unable to add ruby code declaration block to:"<<this;
+                        // DON'T delete.
+                        // block->deleteLater();
+                    } else {
+                        loadCheckForChildrenOK= true;
+                    }
+                } else {
+                    uDebug()<<" LoadFromXMI: Got strange tag in text block stack:"<<name<<", ignoring";
+                }
 
                 node = element.nextSibling();
                 element = node.toElement();
@@ -284,15 +272,15 @@ void RubyClassifierCodeDocument::loadChildTextBlocksFromNode(QDomElement & root)
         telement = tnode.toElement();
     }
 
-    if(!loadCheckForChildrenOK)
+    if (!loadCheckForChildrenOK)
     {
         CodeDocument * test = dynamic_cast<CodeDocument*>(this);
-        if(test)
+        if (test)
         {
             uWarning()<<" loadChildBlocks : unable to initialize any child blocks in doc: "<<test->getFileName()<<" "<<this;
         } else {
             HierarchicalCodeBlock * hb = dynamic_cast<HierarchicalCodeBlock*>(this);
-            if(hb)
+            if (hb)
                 uWarning()<<" loadChildBlocks : unable to initialize any child blocks in Hblock: "<<hb->getTag()<<" "<<this;
             else
                 uDebug()<<" loadChildBlocks : unable to initialize any child blocks in UNKNOWN OBJ:"<<this;
@@ -302,11 +290,11 @@ void RubyClassifierCodeDocument::loadChildTextBlocksFromNode(QDomElement & root)
 
 RubyClassDeclarationBlock * RubyClassifierCodeDocument::getClassDecl()
 {
-    if(!classDeclCodeBlock)
+    if (!classDeclCodeBlock)
     {
         classDeclCodeBlock = new RubyClassDeclarationBlock (this);
         classDeclCodeBlock->updateContent();
-        classDeclCodeBlock->setTag("ClassDeclBlock");
+        classDeclCodeBlock->setTag(QLatin1String("ClassDeclBlock"));
     }
     return classDeclCodeBlock;
 }
@@ -343,9 +331,9 @@ void RubyClassifierCodeDocument::updateContent()
     const CodeClassFieldList * cfList = getCodeClassFieldList();
     CodeClassFieldList::const_iterator it = cfList->begin();
     CodeClassFieldList::const_iterator end = cfList->end();
-    for(; it != end; ++it) {
+    for (; it != end; ++it) {
         CodeClassField * field = *it;
-        if(field->parentIsAttribute())
+        if (field->parentIsAttribute())
             field->setWriteOutMethods(gen->getAutoGenerateAttribAccessors());
         else
             field->setWriteOutMethods(gen->getAutoGenerateAssocAccessors());
@@ -398,19 +386,19 @@ void RubyClassifierCodeDocument::updateContent()
     // declare public, protected and private methods, attributes (fields).
     // set the start text ONLY if this is the first time we created the objects.
     bool createdPublicBlock = publicBlock == 0 ? true : false;
-    publicBlock = myClassDeclCodeBlock->getHierarchicalCodeBlock("publicBlock","Public Items", 0);
+    publicBlock = myClassDeclCodeBlock->getHierarchicalCodeBlock(QLatin1String("publicBlock"), QLatin1String("Public Items"), 0);
     if (createdPublicBlock)
-        publicBlock->setStartText("public");
+        publicBlock->setStartText(QLatin1String("public"));
 
     bool createdProtBlock = protectedBlock == 0 ? true : false;
-    protectedBlock = myClassDeclCodeBlock->getHierarchicalCodeBlock("protectedBlock","Protected Items", 0);
-    if(createdProtBlock)
-        protectedBlock->setStartText("protected");
+    protectedBlock = myClassDeclCodeBlock->getHierarchicalCodeBlock(QLatin1String("protectedBlock"), QLatin1String("Protected Items"), 0);
+    if (createdProtBlock)
+        protectedBlock->setStartText(QLatin1String("protected"));
 
     bool createdPrivBlock = privateBlock == 0 ? true : false;
-    privateBlock = myClassDeclCodeBlock->getHierarchicalCodeBlock("privateBlock","Private Items", 0);
-    if(createdPrivBlock)
-        privateBlock->setStartText("private");
+    privateBlock = myClassDeclCodeBlock->getHierarchicalCodeBlock(QLatin1String("privateBlock"), QLatin1String("Private Items"), 0);
+    if (createdPrivBlock)
+        privateBlock->setStartText(QLatin1String("private"));
 
     // NOW create document in sections..
     // now we want to populate the body of our class
@@ -460,7 +448,7 @@ void RubyClassifierCodeDocument::updateContent()
 
     // get/create the method codeblock
     // public methods
-    HierarchicalCodeBlock * pubMethodsBlock = publicBlock->getHierarchicalCodeBlock("pubMethodsBlock", "", 1);
+    HierarchicalCodeBlock * pubMethodsBlock = publicBlock->getHierarchicalCodeBlock(QLatin1String("pubMethodsBlock"), QString(), 1);
     CodeComment * pubMethodsComment = pubMethodsBlock->getComment();
     bool forceDoc = pol->getCodeVerboseDocumentComments();
     // set conditions for showing this comment
@@ -470,7 +458,7 @@ void RubyClassifierCodeDocument::updateContent()
         pubMethodsComment->setWriteOutText(true);
 
     // protected methods
-    HierarchicalCodeBlock * protMethodsBlock = protectedBlock->getHierarchicalCodeBlock("protMethodsBlock", "", 1);
+    HierarchicalCodeBlock * protMethodsBlock = protectedBlock->getHierarchicalCodeBlock(QLatin1String("protMethodsBlock"), QString(), 1);
     CodeComment * protMethodsComment = protMethodsBlock->getComment();
     // set conditions for showing this comment
     if (!forceDoc && !hasClassFields() && !hasOperationMethods)
@@ -479,7 +467,7 @@ void RubyClassifierCodeDocument::updateContent()
         protMethodsComment->setWriteOutText(true);
 
     // private methods
-    HierarchicalCodeBlock * privMethodsBlock = privateBlock->getHierarchicalCodeBlock("privMethodsBlock", "", 1);
+    HierarchicalCodeBlock * privMethodsBlock = privateBlock->getHierarchicalCodeBlock(QLatin1String("privMethodsBlock"), QString(), 1);
     CodeComment * privMethodsComment = privMethodsBlock->getComment();
     // set conditions for showing this comment
     if (!forceDoc && !hasClassFields() && !hasOperationMethods)
@@ -491,7 +479,7 @@ void RubyClassifierCodeDocument::updateContent()
     //
 
     // public
-    pubConstructorBlock = pubMethodsBlock->getHierarchicalCodeBlock("constructionMethods", "Constructors", 1);
+    pubConstructorBlock = pubMethodsBlock->getHierarchicalCodeBlock(QLatin1String("constructionMethods"), QLatin1String("Constructors"), 1);
     // special condiions for showing comment: only when autogenerateding empty constructors
     // Although, we *should* check for other constructor methods too
     CodeComment * pubConstComment = pubConstructorBlock->getComment();
@@ -501,7 +489,7 @@ void RubyClassifierCodeDocument::updateContent()
         pubConstComment->setWriteOutText(true);
 
     // protected
-    protConstructorBlock = protMethodsBlock->getHierarchicalCodeBlock("constructionMethods", "Constructors", 1);
+    protConstructorBlock = protMethodsBlock->getHierarchicalCodeBlock(QLatin1String("constructionMethods"), QLatin1String("Constructors"), 1);
     // special condiions for showing comment: only when autogenerateding empty constructors
     // Although, we *should* check for other constructor methods too
     CodeComment * protConstComment = protConstructorBlock->getComment();
@@ -511,7 +499,7 @@ void RubyClassifierCodeDocument::updateContent()
         protConstComment->setWriteOutText(true);
 
     // private
-    privConstructorBlock = privMethodsBlock->getHierarchicalCodeBlock("constructionMethods", "Constructors", 1);
+    privConstructorBlock = privMethodsBlock->getHierarchicalCodeBlock(QLatin1String("constructionMethods"), QLatin1String("Constructors"), 1);
     // special condiions for showing comment: only when autogenerateding empty constructors
     // Although, we *should* check for other constructor methods too
     CodeComment * privConstComment = privConstructorBlock->getComment();
@@ -522,7 +510,7 @@ void RubyClassifierCodeDocument::updateContent()
 
     // get/create the accessor codeblock
     // public
-    HierarchicalCodeBlock * pubAccessorBlock = pubMethodsBlock->getHierarchicalCodeBlock("accessorMethods", "Accessor Methods", 1);
+    HierarchicalCodeBlock * pubAccessorBlock = pubMethodsBlock->getHierarchicalCodeBlock(QLatin1String("accessorMethods"), QLatin1String("Accessor Methods"), 1);
     // set conditions for showing section comment
     CodeComment * pubAccessComment = pubAccessorBlock->getComment();
     if (!forceDoc && !hasClassFields())
@@ -531,7 +519,7 @@ void RubyClassifierCodeDocument::updateContent()
         pubAccessComment->setWriteOutText(true);
 
     // protected
-    HierarchicalCodeBlock * protAccessorBlock = protMethodsBlock->getHierarchicalCodeBlock("accessorMethods", "Accessor Methods", 1);
+    HierarchicalCodeBlock * protAccessorBlock = protMethodsBlock->getHierarchicalCodeBlock(QLatin1String("accessorMethods"), QLatin1String("Accessor Methods"), 1);
     // set conditions for showing section comment
     CodeComment * protAccessComment = protAccessorBlock->getComment();
     if (!forceDoc && !hasClassFields())
@@ -540,7 +528,7 @@ void RubyClassifierCodeDocument::updateContent()
         protAccessComment->setWriteOutText(true);
 
     // private
-    HierarchicalCodeBlock * privAccessorBlock = privMethodsBlock->getHierarchicalCodeBlock("accessorMethods", "Accessor Methods", 1);
+    HierarchicalCodeBlock * privAccessorBlock = privMethodsBlock->getHierarchicalCodeBlock(QLatin1String("accessorMethods"), QLatin1String("Accessor Methods"), 1);
     // set conditions for showing section comment
     CodeComment * privAccessComment = privAccessorBlock->getComment();
     if (!forceDoc && !hasClassFields())
@@ -550,18 +538,18 @@ void RubyClassifierCodeDocument::updateContent()
 
     // now, 2 sub-sub sections in accessor block
     // add/update accessor methods for attributes
-    HierarchicalCodeBlock * pubStaticAccessors = pubAccessorBlock->getHierarchicalCodeBlock("pubStaticAccessorMethods", "", 1);
-    HierarchicalCodeBlock * pubRegularAccessors = pubAccessorBlock->getHierarchicalCodeBlock("pubRegularAccessorMethods", "", 1);
+    HierarchicalCodeBlock * pubStaticAccessors = pubAccessorBlock->getHierarchicalCodeBlock(QLatin1String("pubStaticAccessorMethods"), QString(), 1);
+    HierarchicalCodeBlock * pubRegularAccessors = pubAccessorBlock->getHierarchicalCodeBlock(QLatin1String("pubRegularAccessorMethods"), QString(), 1);
     pubStaticAccessors->getComment()->setWriteOutText(false); // never write block comment
     pubRegularAccessors->getComment()->setWriteOutText(false); // never write block comment
 
-    HierarchicalCodeBlock * protStaticAccessors = protAccessorBlock->getHierarchicalCodeBlock("protStaticAccessorMethods", "", 1);
-    HierarchicalCodeBlock * protRegularAccessors = protAccessorBlock->getHierarchicalCodeBlock("protRegularAccessorMethods", "", 1);
+    HierarchicalCodeBlock * protStaticAccessors = protAccessorBlock->getHierarchicalCodeBlock(QLatin1String("protStaticAccessorMethods"), QString(), 1);
+    HierarchicalCodeBlock * protRegularAccessors = protAccessorBlock->getHierarchicalCodeBlock(QLatin1String("protRegularAccessorMethods"), QString(), 1);
     protStaticAccessors->getComment()->setWriteOutText(false); // never write block comment
     protRegularAccessors->getComment()->setWriteOutText(false); // never write block comment
 
-    HierarchicalCodeBlock * privStaticAccessors = privAccessorBlock->getHierarchicalCodeBlock("privStaticAccessorMethods", "", 1);
-    HierarchicalCodeBlock * privRegularAccessors = privAccessorBlock->getHierarchicalCodeBlock("privRegularAccessorMethods", "", 1);
+    HierarchicalCodeBlock * privStaticAccessors = privAccessorBlock->getHierarchicalCodeBlock(QLatin1String("privStaticAccessorMethods"), QString(), 1);
+    HierarchicalCodeBlock * privRegularAccessors = privAccessorBlock->getHierarchicalCodeBlock(QLatin1String("privRegularAccessorMethods"), QString(), 1);
     privStaticAccessors->getComment()->setWriteOutText(false); // never write block comment
     privRegularAccessors->getComment()->setWriteOutText(false); // never write block comment
     // now add in accessors as appropriate
@@ -593,7 +581,7 @@ void RubyClassifierCodeDocument::updateContent()
     // setup/get/create the operations codeblock
 
     // public
-    pubOperationsBlock = pubMethodsBlock->getHierarchicalCodeBlock("operationMethods", "Operations", 1);
+    pubOperationsBlock = pubMethodsBlock->getHierarchicalCodeBlock(QLatin1String("operationMethods"), QLatin1String("Operations"), 1);
     // set conditions for showing section comment
     CodeComment * pubOcomment = pubOperationsBlock->getComment();
     if (!forceDoc && !hasOperationMethods)
@@ -602,7 +590,7 @@ void RubyClassifierCodeDocument::updateContent()
         pubOcomment->setWriteOutText(true);
 
     //protected
-    protOperationsBlock = protMethodsBlock->getHierarchicalCodeBlock("operationMethods", "Operations", 1);
+    protOperationsBlock = protMethodsBlock->getHierarchicalCodeBlock(QLatin1String("operationMethods"), QLatin1String("Operations"), 1);
     // set conditions for showing section comment
     CodeComment * protOcomment = protOperationsBlock->getComment();
     if (!forceDoc && !hasOperationMethods)
@@ -611,7 +599,7 @@ void RubyClassifierCodeDocument::updateContent()
         protOcomment->setWriteOutText(true);
 
     //private
-    privOperationsBlock = privMethodsBlock->getHierarchicalCodeBlock("operationMethods", "Operations", 1);
+    privOperationsBlock = privMethodsBlock->getHierarchicalCodeBlock(QLatin1String("operationMethods"), QLatin1String("Operations"), 1);
     // set conditions for showing section comment
     CodeComment * privOcomment = privOperationsBlock->getComment();
     if (!forceDoc && !hasOperationMethods)
