@@ -14,6 +14,7 @@
 // app includes
 #include "template.h"
 #include "classifier.h"
+#include "documentationwidget.h"
 #include "umldoc.h"
 #include "uml.h"
 #include "dialog_utils.h"
@@ -83,6 +84,9 @@ void UMLTemplateDialog::setupDialog()
 
     mainLayout->addWidget(m_pValuesGB);
 
+    m_docWidget = new DocumentationWidget(m_pTemplate, this);
+    mainLayout->addWidget(m_docWidget);
+
     m_pTypeCB->setEditable(true);
     m_pTypeCB->setDuplicatesEnabled(false); // only allow one of each type in box
     m_pTypeCB->setCompletionMode(KGlobalSettings::CompletionPopup);
@@ -164,6 +168,7 @@ bool UMLTemplateDialog::apply()
     m_pTemplate->setName(name);
 
     m_pTemplate->setStereotype(m_pStereoTypeLE->text());
+    m_docWidget->apply();
 
     return true;
 }
